from setuptools import setup

setup(name='django-dellavrite',
      version='0.0',
      description='Cheat for ws',
      packages=['django-dellavrite'],
      author_email='delavrite@gmail.com',
      zip_safe=False)
